function cfg = initialise

%% data

%what is the name of the variable that contains the data stored in your
%behavioural .mat file?
cfg.dataVarName = 'data';


%% section markers



%names of start and end of the trial. recordpos specifies the column
%number where the recordname will be found. recordposval returns a value from
%this same row in that column. If we don't need to return any info from
%that row, set the values to -1. Record info should specify the start and
%the end of the trial.
cfg.ELidentifiers.recordname = {'TRIALID', 'END'};
cfg.ELidentifiers.recordpos = [3 3];
cfg.ELidentifiers.recordposval = [4 2];

%as above, for sections
cfg.ELidentifiers.secname = {'SYNCTIME', 'BOX'};
cfg.ELidentifiers.secpos = [3 4];
cfg.ELidentifiers.secposval = [-1 -1];


%decision time info. Leave blank and set pos vals to -1 if no RT vals in
%the eye data file. Same for response (resp) values.
cfg.ELidentifiers.RTname = 'DECISION';
cfg.ELidentifiers.RTpos = 3;
cfg.ELidentifiers.RTposval = 6;
cfg.ELidentifiers.respname = 'RESPONSE';
cfg.ELidentifiers.resppos = 3;
cfg.ELidentifiers.respposval = 5;

%other info that you might want to grab from the .asc file
cfg.ELidentifiers.trialInfoname = {'BLOCKID','STIMID'};
cfg.ELidentifiers.trialInfopos = [3 3];
cfg.ELidentifiers.trialInfoposval = [4 4];
cfg.ELidentifiers.trialInfoBefore = [1 0]; %1=before trial info, 0=after trial info


%% fixation definition


%use first fixation from the trial? 1=yes. Often removed because a fixation
%cross or some other stimulus on the preceding page defines the location of
%the first fixation
cfg.firstfix = 1;

%which sections are the ones we want to remove first fixation from? 1st
%section is trial onset, last section is the one just before the end of the
%trial. Set to blank ([]) or -1 if irrelevant. Has no effect if
%cfg.firstfix == 1
cfg.firstfixsec = 2;

cfg.minFixDur = 100; %minimum duration for a fixation to be counted as a fixation, in msec


%% Specify ROIs

%unnecessary additional info that I just want saved to the data file
cfg.ROI.spaceSize = 77.28;
cfg.ROI.boxSize = 134;
cfg.ROI.topLeft = [255.28 77.28];
cfg.ROI.topLeftX = 255.28;
cfg.ROI.topLeftY = 77.28;

%if you specify ROIs, it assumes this will be the same for every trial and
%for every file you select when you run the ELextract script. Currently
%unable to handle files with varying ROIs between trials. If that is how
%your data looks, you should set all these variables to be blank (either {}
                                                                  %or []). Importantly, you should specify
cfg.ROI.name = {'1','2','3','4','5','6','7','8','9','10','11','12','13',...
    '14','15','16'};
cfg.ROI.x1 = [255.25 255.25 255.25 255.25 466.68 466.68 466.68 466.68 ...
              678.36 678.36 678.36 678.36 890.04 890.04 890.04 890.04 0];
cfg.ROI.y1 = [77.28, 288.96, 500.64, 712.32, 77.28, 288.96, 500.64, 712.32, ...
              77.28, 288.96, 500.64, 712.32, 77.28, 288.96, 500.64, 712.32 924];

cfg.ROI.x2 = cfg.ROI.x1 + cfg.ROI.boxSize; %[] is blank here
cfg.ROI.y2 = cfg.ROI.y1 + cfg.ROI.boxSize;


%% recalibration

%If you want to adjust the ROIs based on the eye tracker calibration error,
%you will need to set these variables. Otherwise, set them to 0.
%
%If using optimisation, be sure to read Vadillo et al (2015)'s paper to
%make sure your data do not violate any of the assumptions. If they do,
%then you'll end up with nonsense data...! Assumes people will actually
%look at the ROIs. If they don't (e.g. Reingold, Pomplun, Charness et al,
%2001), then you might find this distorts your data
cfg.screenwidthpix = 1280; %screen width in pixels
cfg.screenheightpix = 1024;
cfg.viewDistcm = 60; %participant distance from screen, in cm
cfg.stimSize = 33.7; %pixel size of stimulus, if known. set to -1 otherwise
cfg.scrWidthcm = 34; %width of screen in cm (not including border of screen)
cfg.scrHeightcm = 27.4;

cfg.adjustROI = 1; %adjust ROIs to accomodate tracking error? 1=manual, 2=optimisation

%0=not plot; 1=plot all, 2=plot overcalibrated
cfg.plotRecal = 2; %plots the recalibration, if adjustROI == 2 and ROIs specified.
cfg.waitPlot = 0; %hold the plots until a button is pressed? 1=yes

%% update command window


cfg.idxDisp = -1; %display the "idx"th line being processed to the command window (non-essential)
cfg.trialDisp = 1; %display the nth trial being processed to the command window (non-essential)


%% trial duplicates

%You might have set up your study so that if participants respond
%incorrectly they have to run through the trial again. As a result, you
%will have duplicate trials in the eye data file that should be ignored. If
%so, set this variable to 1, otherwise 0
cfg.trialDuplicates = 1;


%% saving data

cfg.writeraw = 1; %write the raw fixation details to a .csv file? 1=yes
cfg.movefile = 1; %move data files into a subfolder? 1=yes


%% misc settings

%other settings that you shouldn't need to change
cfg=miscSettings(cfg);


%% --------------------------------------------------

%% OTHER SETTINGS, HOPEFULLY YOU WONT NEED TO DEAL WITH THESE


    function cfg=miscSettings(cfg)

        cfg.readall = 1; 
        cfg.readmat = 1; 

        cfg.debugTrial = -1;
        cfg.debugIdx = -1;

        cfg.writesumfile = 0; %write summary data to .csv file? 1=yes
        
        cfg.nFixperGroup = -1; %no of fixations to bound together when running eyeCorrect optimisation. -1 does it by-section
        cfg.splitROIs = 1; %if set to 1, splits up the ROIs into smaller boxes to improve recalibration fit. Only applies if cfg.adjustROI == 1
        cfg.splitDeg = 1.3; %degrees to split ROIs into. Increase value to increase recalibration speed, decrease to improve accuracy

        if cfg.stimSize > 0
            if isfield(cfg, 'screenwidthpix') && cfg.screenwidthpix > 0
                cfg.pixperdegW = cfg.screenwidthpix/(visang(cfg.viewDistcm,[],cfg.scrWidthcm));
            end
            if isfield(cfg, 'screenheightpix') && cfg.screenheightpix > 0
                cfg.pixperdegH = cfg.screenheightpix/(visang(cfg.viewDistcm,[],cfg.scrHeightcm));
            end
            
            if cfg.adjustROI == 1
                recalDegrees = 0.7;
                cfg.recalSize = [cfg.pixperdegW*recalDegrees cfg.pixperdegH*recalDegrees];
                
                cfg=plotPotentialCal(cfg);
                
            end
        end
        

    end

%% 
    function cfg=plotPotentialCal(cfg)
        
        breakpoint = 0;
        while breakpoint ~= 2
            
            clf; figure(1);
            for r = 1:length(cfg.ROI.name)
                rectangle('Position', [cfg.ROI.x1(r)-cfg.recalSize(1) cfg.ROI.y1(r)-cfg.recalSize(2) ...
                    cfg.ROI.x2(r)-cfg.ROI.x1(r)+(cfg.recalSize(1)*2) cfg.ROI.y2(r)-cfg.ROI.y1(r)+(cfg.recalSize(2)*2)]);
            end
            
            for r = 1:length(cfg.ROI.name)
                rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
                        cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)], 'LineStyle', '--');
            end

            axis([0 cfg.screenwidthpix 0 cfg.screenheightpix]);
            title('Solid = New ROI, Dashed = Original');
            
            changeSize = input(sprintf('Use (2), increase (1), or\ndecrease(0) ROI size [%1.2f deg]?: ', ...
                                cfg.recalSize(1)/cfg.pixperdegW));


            incr = 0.05; %increment 
            
            if isempty(changeSize) || changeSize == 2
                breakpoint = 2;
                fprintf('Accepted: increase ROI by (%1.2f, %1.2f) pix (%1.2f deg)\n',...
                    cfg.recalSize(1), cfg.recalSize(2), cfg.recalSize(1)/cfg.pixperdegW);
            elseif changeSize == 0 && cfg.ROI.x1(1)+cfg.recalSize(1)-(cfg.pixperdegW*incr) >= cfg.ROI.x1(1) %dont go smaller than ROI size
                cfg.recalSize = cfg.recalSize - (cfg.pixperdegW*incr);
            elseif changeSize == 1
                cfg.recalSize = cfg.recalSize + (cfg.pixperdegW*incr);
            end
            
            clear changeSize;
            
        end
        
        close all;
        
    end %end function


end

    